function [ newdata, error ] = dsetCorrSamp( data, sample )
%PRECORRSAMP uses the drEEM's ZAP script for correcting intensity values 
%on the selected sample

%% === INIT
newdata = data;
error = {};
emAxe = data.Em; % rows
exAxe = data.Ex; % cols

%% === INFO
label = 'Correct samples';
info = strcat({ ...
    'This removes a part of the selected samples containing faulty data', ...
    'Samples in the list are comma-sepparated', ...
    'Ex/Em correction ranges are bracketted', ...
    'For NO correction in one dimension just input empty brackets []', ...
    'This processing uses the drEEM''s ZAP script', ...
    'ZAP sets data to missing in selected samples and at specified wavelengths', ...
    'Type HELP ZAP in MATLAB''s console for more info', ...
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
dlg_title = 'Correct samples';
prompt = { ...
    'Observation number:', ...
    'Ex range to correct (nm):', ...
    'Em range to correct (nm):', ...
    };
num_lines = 1;
def = {num2str(sample), ...
    ['[' num2str(exAxe(1)) ' ' num2str(exAxe(end)) ']'], ...
    ['[' num2str(emAxe(1)) ' ' num2str(emAxe(end)) ']']};
user_info = inputdlg(prompt,dlg_title,num_lines,def);
if isempty(user_info)
    error = [error, {'ERROR: EEMlab:dsetCorrSamp:userSelectedCancel'}];
    return;
else
    remain = user_info{1};
    slist = [];
    i = 1;
    while ~isempty(remain)
        [token, remain] = strtok(remain,',');
        slist(i) = str2double(token); % list of samples
        i = i + 1;
    end
    [token, remain] = strtok(user_info{2});
    ExRange = [str2double(token(2:end)) str2double(remain(1:end-1))];
    if isnan(ExRange)
        ExRange = [];
    end
    [token, remain] = strtok(user_info{3});
    EmRange = [str2double(token(2:end)) str2double(remain(1:end-1))];
    if isnan(EmRange)
        EmRange = [];
    end
    
end

%% === UPDATE DATASET
newdata = zap(data,slist,EmRange,ExRange);

end