function [ newdata, error ] = dsetDwsampleEm( data )
%DSETDWSAMPLEEM downsamples the EEM dataset to the new defined Emission 
%wavelengths

%% === INIT
newdata = data;
error = {};

%% === INFO

label = 'Downsample emission wavelengths';
info = strcat({ ...
    'The emission spectrum will be downsampled to the new wavelengths', ...
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
dlg_title = 'Downsample Em';
prompt = { ...
    'Emission range (nm):', ...
    'Emission step (nm):', ...
    };
num_lines = 1;
def = { ...
    ['[' num2str(min(data.Em)) ' ' num2str(max(data.Em)) ']'], ...
    num2str(min(diff(data.Em))), ...
    };
user_info = inputdlg(prompt,dlg_title,num_lines,def);
if isempty(user_info)
    error = [error, {'ERROR: EEMlab:dsetDwsampleEm:userSelectedCancel'}];
    return;
else
    [token, remain] = strtok(user_info{1});
    em_start = str2double(token(2:end));
    em_end = str2double(remain(1:end-1));
    em_step = str2double(user_info{2});
    Em = data.Em;
    newEm = (em_start:em_step:em_end)';
end

%% === UPDATE DATASET
method = 'spline';
newX = zeros(data.nSample,length(newEm),data.nEx);
for i=1:data.nSample
    intVal = reshape(data.X(i,:,:),data.nEm,data.nEx);
    newIntVal = interp1(Em,intVal,newEm,method);
    newIntVal(newIntVal < 0) = 0;
    newIntVal(newIntVal > max(intVal(:))) = max(intVal(:));
    newX(i,:,:) = newIntVal;
end
newdata.Em = newEm;
newdata.nEm = length(newEm);
newdata.X = newX;

end