function [ newdata, error ] = dsetDwsampleEx( data )
%DSETDWSAMPLEEX downsamples the EEM dataset to the new defined Excitation 
%wavelengths

%% === INIT
newdata = data;
error = {};

%% === INFO

label = 'Downsample excitation wavelengths';
info = strcat({ ...
    'The excitation spectrum will be downsampled to the new wavelengths', ...
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
dlg_title = 'Downsample Ex';
prompt = { ...
    'Excitation range (nm):', ...
    'Excitation step (nm):', ...
    };
num_lines = 1;
def = { ...
    ['[' num2str(min(data.Ex)) ' ' num2str(max(data.Ex)) ']'], ...
    num2str(min(diff(data.Ex))), ...
    };
user_info = inputdlg(prompt,dlg_title,num_lines,def);
if isempty(user_info)
    error = [error, {'ERROR: EEMlab:dsetDwsampleEx:userSelectedCancel'}];
    return;
else
    [token, remain] = strtok(user_info{1});
    ex_start = str2double(token(2:end));
    ex_end = str2double(remain(1:end-1));
    ex_step = str2double(user_info{2});
    Ex = data.Ex;
    newEx = (ex_start:ex_step:ex_end)';
end

%% === UPDATE DATASET
method = 'spline';
newX = zeros(data.nSample,data.nEm,length(newEx));
for i=1:data.nSample
    intVal = reshape(data.X(i,:,:),data.nEm,data.nEx)'; % primera matriz traspuesta
    newIntVal = interp1(Ex,intVal,newEx,method);
    newIntVal(newIntVal < 0) = 0;
    newIntVal(newIntVal > max(intVal(:))) = max(intVal(:));
    newX(i,:,:) = newIntVal';
end
newdata.Ex = newEx;
newdata.nEx = length(newEx);
newdata.X = newX;

end