function [ newdata, error ] = dsetNormRvs( data )
%MDLSNORMRVS uses the drEEM's NORMEEM to REVERSE normalization in all the
%computed models and in the full EEM dataset

%% === INIT
newdata = data;
error = {};

%% === ERROR CHECKING
if ~isfield(data,'Xnotscaled')
    info = strcat({ ...
        'The dataset has not been normalized', ...
        'Please normalize the dataset first', ...
        });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [error, {'ERROR: EEMlab:mdlsNormRvs:noPreviousNormalizationDone'}];
    return;
elseif ~isfield(data,'modelNames') || isempty(data.modelNames)
    info = strcat({ ...
        'The dataset has not been still modeled', ...
        'Please create exploratory or refined models first', ...
        });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [error, {'ERROR: EEMlab:mdlsNormRvs:noModelsToProcess'}];
    return;
end

%% === INFO
label = 'Reverse normalization';
info = strcat({ ...
    'Reverses the normalization for the dataset', ...
    'Reverses the normalization for the refined and exploratory models', ...
    'Splitted models are NOT reversed', ...
    'True scores for all the models after reversion', ...
    'Type HELP NORMEEM in MATLAB''s console for more info', ...
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
models = data.modelNames;
myfactors = nan(1,length(models));
EXlist = false(length(models),1); % list of Exploratory (OUTLIERTEST) models
RFlist = false(length(models),1); % list Refined (RANDINITANAL) models
SPlist = false(length(models),1); % list Validated (SPLITDS, SPLITANALYSIS, SPLITVALIDATION) models
for i = 1 : length(models)
    tok = strtok(models{i},'Model');
    myfactors(i) = str2double(tok(1));
    if strfind(models{i},'exploratory')
        EXlist(i,1) = true;
    elseif strfind(models{i},'refined')
        RFlist(i,1) = true; 
    elseif strfind(models{i},'splitted')
        SPlist(i,1) = true;
    end
end

%% === UPDATE DATASET
% This REVERSES normalization in ALL the computed models and the FULL dataset
if any(EXlist|RFlist)
    if all(size(data.Xnotscaled) == size(data.X))
        factors = myfactors(EXlist|RFlist);
        newdata = normeem(data,'reverse',factors);
    else
        info = strcat({ ...
            'The size of the exploratory dataset do not match', ...
            'with the size of the original not scaled dataset', ...
            'Please consider of repeating the exploratory analysis', ...
            'using ALL the (Ex/Em) data available in the dataset', ...
            'Otherwise it is NOT possible to reverse the normalization', ...
            });
        label = 'Error';
        icon = 'error';
        uiwait(msgbox(info,label,icon,'modal'));
        error = [error, {'ERROR: EEMlab:mdlsNormRvs:notMatchingDimensions'}];
        return;
    end
end
% Splitted models are NOT reversed as there are not enough information in
% splits to reverse normalization (??)
% if any(SPlist)
%         factors = myfactors(SPlist);
%         for i = 1 : length(data.Split)
%             newdata = normeem(data.Split(i),'reverse',factors);
%         end
% end

end