function [ newdata, error ] = dsetRmOutByTag( data )
%
%PRERMOUTLIERS removes the selected samples (outliers) from the data
% structure
% It uses the drEEM's SUBDATASET script

%% === INIT
newdata = data;
error = {};

%% === INFO
label = 'Remove outliers by tag';
info = strcat({ ...
    'This removes the outliers tagged with the selected tag', ...
    'This processing uses the drEEM''s SUBDATASET script', ...
    'SUBDATASET subsets a dataset by removing samples and/or wavelengths', ...
    'Type HELP SUBDATASET in MATLAB''s console for more info', ...
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
if isfield(data,'tagNames')
    tags = data.tagNames;
    name = 'Categories of tags';
    [selected,ok] = listdlg('Name',name,...
        'PromptString','Select the category:',...
        'SelectionMode','single',...
        'ListSize',[160 100],...
        'ListString',tags);
    if ~ok
        error = [error, {'ERROR: EEMlab:dsetRmOutByTag:userSelectedCancel'}];
        return;
    else
        stag = tags(selected);
    end
else
    info = strcat({ ...
        'No tags are loaded in the dataset', ...
        'Please load tags', ...
        });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [error, {'ERROR: EEMlab:dsetRmOutByTag:noTagsLoaded'}];
    return;
end

taglist = unique(data.(stag{:}));
name = 'Tags loaded';
[selected,ok] = listdlg('Name',name,...
    'PromptString','Select the tag to remove:',...
    'SelectionMode','multiple',...
    'ListSize',[160 100],...
    'ListString',taglist);
if ~ok
    error = [error, {'ERROR: EEMlab:dsetRmOutByTag:userSelectedCancel'}];
    return;
else
    outliertags = taglist(selected(:));
end

%% === UPDATE DATASET
outEm = [];
outEx = [];
newdata = subdataset(data,[stag outliertags'],outEm,outEx);

end