function [ newdata, error ] = dsetRmScatter( data )
%PRERMSCATTER corrects the Raman & Rayleigh scattering
% A width band (nm) is defined and intensity is deleted to the left and
% to the right of the Rayleigh/Raman central frequencies
% It uses the drEEM's SMOOTHEEMS script

%% === INIT
newdata = data;
error = {};

% %% === INFO
% label = 'Scattering correction';
% info = strcat({ ...
%     'Rayleigh and Raman scattering effects will be removed', ...
%     'see drEEM toolbox for more info', ...
%     });
% uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
dlg_title = 'Scattering correction';
prompt = { ...
    '1st order Rayleigh scattering (bandwidth in nm):', ...
    '1st order Raman scattering (bandwidth in nm):', ...
    '2nd order Rayleigh scattering (bandwidth in nm):', ...
    '2nd order Raman scattering (bandwidth in nm):', ...
    'Turn interpolation on/off for [Ray1 Ram1 Ray2 Ram2]:', ...
    'Distance below 1st Rayleigh before zeros (nm):', ...
    };
num_lines = 1;
def = {'[18 15]','[15 15]','[17 18]','[19 18]','[1 1 1 1]','40'};
user_info = inputdlg(prompt,dlg_title,num_lines,def);
if isempty(user_info)
    error = [error, {'ERROR: EEMlab:dsetRmScatter:userSelectedCancel'}];
    return;
else
    [token, remain] = strtok(user_info{1});
    Ray1 = [str2double(token(2:end)) str2double(remain(1:end-1))];
    [token, remain] = strtok(user_info{2});
    Ram1 = [str2double(token(2:end)) str2double(remain(1:end-1))];
    [token, remain] = strtok(user_info{3});
    Ray2 = [str2double(token(2:end)) str2double(remain(1:end-1))];
    [token, remain] = strtok(user_info{4});
    Ram2 = [str2double(token(2:end)) str2double(remain(1:end-1))];
    NaNfilter = textscan(user_info{5}(2:end-1),'%u');
    NaNfilter = NaNfilter{:}';
    d2zero = str2double(user_info{6});
end

%% === UPDATE DATASET
pflag = 0;
newdata = smootheem(data,Ray1,Ram1,Ray2,Ram2,NaNfilter,d2zero,pflag);

end