function [ data, loads, samplelog, datadir, log, error ] = expLoad( )
%
%LODDSETMATF loads an EEM dataset previously stored in a Matlab file

%% === INIT
data = [];
loads = [];
samplelog = [];
datadir = '';
log = {};
error = {};

%% === INFO
label = 'Load MAT file';
info = strcat({ ...
    'This process can take a long time to complete', ...
    'depending on the size of the data to load', ...
    'Please wait until the ''green'' light is ON', ...
    });
uiwait(msgbox(info,label,'help','modal'));

%% === LOAD data
FilterSpec = { ...
    '*.mat','Matlab EEM dataset'; ...
    };
[FileName, PathName, FilterIndex] = uigetfile(FilterSpec,'load data from file', 'MultiSelect','off');
switch FilterIndex
    case 0
        error = [error, {'ERROR: EEMlab:lodDsetMatf:userSelectedCancel'}];
        return;
    case 1
        % Matlab MAT EEM data struct file
        % load of the DATA struct
        tmp = load(strcat(PathName,FileName));
        names = fieldnames(tmp);
        for i = 1 : length(names)
            eval([names{i} '=tmp.' names{i} ';']);
        end
        clear tmp;
        % error checking: does the struct contain the basic drEEM fields?
        if ~isfield(data,'Ex') || ~isfield(data,'Em') || ~isfield(data,'X') ...
                || ~isfield(data,'IntensityUnit') || ~isfield(data,'nEx') ...
                || ~isfield(data,'nEm') || ~isfield(data,'nSample')
            error{end+1} = 'ERROR EEMlab:lodDsetMatf:dataStructWrong';
            return;
        end
        datadir = PathName;
        
        % load of the LOG file
        ind = strfind(FileName,'.');
        logfilename = [FileName(1:ind(end)) 'log'];
        [log, err] = txtfile2cellarray(strcat(PathName,logfilename));% we recover the previous LOG info
        if ~isempty(err)
            label = 'Load MAT file';
            info = {'Load of the experiment file in MATLAB format', ...
                ['The correspondent ''' logfilename ''' file is not found in the directory'], ...
                'The experiment will continue without including the previous log information'};
            uiwait(warndlg(info,label,'modal'));
            log = {'Load of the experiment file in MATLAB format', ...
                ['The correspondent ''' logfilename ''' file is not found in the directory'], ...
                'The experiment will continue without including the previous log information'};
            return;
        end
end

end