function [ newoutputdir, etime, error ] = expSaveMat( data, loads, samplelog, log, datadir )
%
% DSETSAVEMAT saves the data in a MAT file

%% === INIT
etime = NaN;
error = {};
newoutputdir = {};

%% === INFO
label = 'Save experiment';
info = strcat({ ...
    'This process can take a long time to complete', ...
    'depending on the size of the data to save', ...
    'Please wait until the ''green'' light is ON', ...
    });
uiwait(msgbox(info,label,'warn','modal'));

%% === ERROR CHECKING
if ~isstruct(data) || ~isstruct(loads) || ~isstruct(samplelog)
    % the passed variable is not a drEEM data struct
    error = {'ERROR EEMlab:expSaveMat:dataStructWrong'};
    return;
elseif ~isfield(data,'Ex') || ~isfield(data,'Em') || ~isfield(data,'X') ...
        || ~isfield(data,'IntensityUnit') || ~isfield(data,'nEx') ...
        || ~isfield(data,'nEm') || ~isfield(data,'nSample')
    % the struct does not contain the basic drEEM data fields
    error = {'ERROR EEMlab:expSaveMat:dataStructWrong'};
    return;
end

%% === DATA LOAD
home = pwd; % get current path
if isempty(strfind(datadir,'\OutputFiles'))
    newoutputdir = strcat(datadir,'\OutputFiles');
else
    newoutputdir = datadir; % load of a a MAT file in 'OutputFiles'
end
if ~exist(newoutputdir,'dir')
    mkdir(newoutputdir);
end
cd(newoutputdir);

filterSpec = { ...
    '*.mat','EEMlab MAT-file'; ...
    };
defaultName = 'EEMlab';
[FileName, PathName, FilterIndex] = uiputfile(filterSpec, 'Save Experiment as', defaultName);
switch FilterIndex
    case 0,
        error = {'ERROR EEMlab:expSaveMat:userSelectedCancel'};
        return;
    case 1,
        s = whos('data');
        sGB = s.bytes/1e9; % data size in GB
        tic;
        if sGB > 2
            version = '-v7.3'; % this is because of the data BIG size
            save(strcat(PathName,FileName),'data','loads','samplelog',version);
        else
            save(strcat(PathName,FileName),'data','loads','samplelog');
        end
        etime = datestr(toc/(24*60*60),'HH:MM:SS');
        logname = [strtok(FileName,'.') '.log'];
        error = cellarray2txtfile(log,strcat(PathName,logname));
        if ~isempty(error)
            return;
        end
end
cd(home);

end