function [ newloads, error ] = lodCalibQs( data, loads, samplelog )
%LODCALIBQS loads the slope for the Quinine Sulphate (QS) dilution series
%Slopes of QS dilution coseries will be automatically loaded and aligned by
%drEEM's alignds as they are numerical values (not filenames) directly
%specified in 'samplelog'. However and to be coherent with the procedure we
%include this (lodCorrDilFactors) step in the loads


%% === INIT
newloads = loads;
error = {};

% %% === INFO
% label = 'LodCalibQs';
% info = strcat({ ...
%     'Loads the slopes for the Quinine Sulphate (QS) dilution series', ...
%     'Slopes are loaded from the metadata file', ...
%     });
% uiwait(msgbox(info,label,'modal'));

%% === ERROR CHECKING
% get the QS slope from samplelog ('loglist')
headers = fieldnames(samplelog);
[tag,ok] = listdlg('Name','Select the metadata tag',...
    'PromptString','Select the tag name to load:',...
    'SelectionMode','single',...
    'ListSize',[160 250],...
    'ListString',headers);
if ~ok
    error = [error, {'ERROR: EEMlab:lodCorrDilFactors:noSamplelogReference'}];
    return;
end
stag = headers(tag); % selected tag

%% === UPDATE DATASET
Q = alignds(samplelog,{data.header,data.filelist},stag);
newloads.Q = Q;

end