function [ newloads, error ] = lodCorrDilFactors( data, loads, samplelog )
%LODCORRDILFACTORS loads dilutions correction factors
%Dilution correction factors will be automatically loaded and aligned by
%drEEM's alignds as they are numerical values (not filenames) directly
%specified in 'samplelog'. However and to be coherent with the procedure we
%include this (lodCorrDilFactors) step in the loads

%% === INIT
newloads = loads;
error = {};
dflag = true; % deblank flag for 'targetsinlist'

%% === INFO
% label = 'LodCorrDilFactors';
% info = strcat({ ...
%     'Loads the dilution factors from metadata file', ...
%     });
% uiwait(msgbox(info,label,'modal'));

%% === ERROR CHECKING
% get the dilution factors from samplelog ('loglist')
headers = fieldnames(samplelog);
[tag,ok] = listdlg('Name','Select the metadata tag',...
    'PromptString','Select the tag name to load:',...
    'SelectionMode','single',...
    'ListSize',[160 250],...
    'ListString',headers);
if ~ok
    error = [error, {'ERROR: EEMlab:lodCorrDilFactors:noSamplelogReference'}];
    return;
end
stag = headers(tag); % selected tag

%% === UPDATE DATASET
dilfac = alignds(samplelog,{data.header,data.filelist},stag);
newloads.dilfac = dilfac;

end
