function [ newloads, error ] = lodCorrSpecFull( data, loads, samplelog )
%LODCORRSPECFULL loads the spectral correctios for the full EEM depending
%on the features of the acquisition device
%Be aware in case of QuantaMaster, that acquire EEMs already spectrally
%corrected!

% === the correspondent MENU has set to VISIBLE=OFF in APPCONFIG script

%% === INIT
newloads = loads;
error = {};
rflag = false; % recursive flag for 'getfilesinfolder'
pflag = false; % prepend flag for 'getfilesinfolder'
dflag = true; % deblank flag for 'targetsinlist'
home = pwd; % get current path

%% === INFO
label = 'Load of spectral correction EEM files';
info = strcat({ ...
    'EEMs for QuantaMaster fluorometer are automatically corrected on acquisition', ...
    'No other action is required', ...
    });
uiwait(msgbox(info,label,'modal'));

%% === ERROR CHECKING
% select folder and get the SPECTRAL CORRECTION filelist ('filelist')
title = 'Select the directory containing the set of SPECTRAL CORRECTION files to load';
folder = uigetdir('',title); % get path to selected folder
if folder == 0 %user selected cancel
    error = [error, {'ERROR: EEMlab:lodCorrSpecFull:userSelectedCancel'}];
    return;
end

filelist = getfilesinfolder(folder,rflag,pflag);
% get the SPECTRAL CORRECTION filelist from samplelog ('loglist')
headers = fieldnames(samplelog);
targets = {'eem corr file','eem spectral correction','eemcorr'};
[in,~,~] = targetsinlist(headers,targets,dflag); % look for some header in the list
if isempty(in)
    error = [error, {'ERROR: EEMlab:lodCorrSpecFull:noSamplelogReference'}];
    return;
end
in = in{:}; % to string
loglist = samplelog.(in);

% match the selected SPECTRAL CORRECTION dataset against the samplelog metadata list
[~,outfle,~] = targetsinlist(loglist,filelist,dflag); % check if samplelog references are in filelist
[~,outlog,~] = targetsinlist(filelist,loglist,dflag); % check if files in folder are referred to in samplelog
if isempty(outfle) % all references in log are IN the folder
    if ~isempty(outlog) % the folder contains extra files
        info = strcat({ ...
            'The folder contains SPECTRAL CORRECTION files with no reference in the ''SampleLog'' metadata file', ...
            'Delete unmatched files from folder and repeat the load', ...
            ' ', ...
            'SPECTRAL CORRECTION files NOT referenced in ''SampleLog'':', ...
            outlog{:}, ...
            });
        label = 'Error';
        icon = 'error';
        uiwait(msgbox(info,label,icon,'modal'));
        error = [ ...
            error, ...
            {'ERROR: EEMlab:lodCorrSpecFull:manyFilesInFolder'}, ...
            {'SPECTRAL CORRECTION files NOT referenced in ''SampleLog'':'}, ...
            outlog{:}, ...
            ];
        return;
    end
else % NOT all the references in log are IN the folder
    info = strcat({ ...
        'This folder does not contain the complete SPECTRAL CORRECTION dataset referred to in the ''SampleLog'' metadata', ...
        'You can complete the dataset and repeat the load', ...
        'OR delete unmatched records from ''SampleLog'' and repeat the metainformation & data loads', ...
        ' ', ...
        'SPECTRAL CORRECTION files NOT stored in folder:', ...
        outfle{:}, ...
        });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [ ...
        error, ...
        {'ERROR: EEMlab:lodCorrSpecFull:incompleteBlankDataset'}, ...
        {'SPECTRAL CORRECTION files NOT stored in folder:'}, ...
        outfle{:}, ...
        ];
    return;
end

%% === DATA LOAD
cd(folder);
[~,format] = strtok(filelist{1},'.');
switch format(2:end)
    case 'txt'
        %QuantaMaster TXT SPECTRAL CORRECTION files
        [X,Emmat,Exmat,filelist,err] = readineems4qms();
        if ~isempty(err)
            error = [error err{:}];
            return;
        end
    case 'csv'
        %Other fluorometers CSV SPECTRAL CORRECTION files: SPEX Fluorolog-3, Fluoromax, Hitachi, Varian, AquaLog
        type = 1; % Ex in cols, Em in rows
        [range,~,err] = getrange(filelist{1});
        headers = [1 1];
        display = 0;
        outdat = 0;
        if isempty(err)
            [X,Emmat,Exmat,filelist,~] = readineems(type,format(2:end),range,headers,display,outdat);
        else
            error = [error err{:}];
            return;
        end
end
cd(home);

%% === UPDATE DATASET
% as Emcor & Excor are SCANS to be used in FDOMCORRECT, now he shoud get
% scans from every matrix!!!! THis is NOT possible
% Emcor = alignds(samplelog,{data.header,data.filelist},{in,filelist,X});
% Excor = ??
% newloads.Emcor = Emcor;
% newloads.Excor = Excor;

end
