function [ newdata, error ] = lodDsetTags( data, samplelog )
%LODTAGS loads experiment tags from samplelog
%Tags are loaded in the already created experiment DATA struct
%Tags can be loaded AFTER the DATA struct creation
%The field TAGLIST is also added to the DATA struct. This contains the
%names of the tags loaded

%% === INIT
newdata = data;
error = {};

%% === INFO

%% === DATA LOAD
headers = fieldnames(samplelog);
name = 'Load tags';
[tags,ok] = listdlg('Name',name,...
    'PromptString','Select the tag name to load:',...
    'SelectionMode','multiple',...
    'ListSize',[160 250],...
    'ListString',headers);
if ~ok
    error = [error, {'ERROR: EEMlab:lodTags:userSelectedCancel'}];
    return;
end

%% === UPDATE DATASET
for i = 1 : length(tags)
    atag = alignds(samplelog,{data.header,data.filelist},headers(tags(i))); % aligned tag
    newdata.(headers{tags(i)}) = atag;
end
newdata.tagNames = headers(tags);

end