function [ newdata, etime, error ] = mdlsExpl( data )
%
% This uses the drEEM's OUTLIERTEST script
%ETIME is the elapsed time on processing the model, in string format

%% === INIT
newdata = data;
etime = '';
error = {};

%% === INFO
label = 'Exploratory analysis';
info = strcat({ ...
    'Look for unusual samples or wavelengths in a dataset (outliers)', ...
    'by generating fast PARAFAC models and evaluating leverages', ...
    'This processing uses the drEEM''s OUTLIERTEST script', ...
    'Type HELP OUTLIERTEST in MATLAB''s console for more info'
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
% if run OUTLIERTEST using stepwise = 'at once' no plots are produced as
% the flag for plots OPTION(3) takes the value '0'. On the other hand,
% running OUTLIERTEST with stepwise 'at a time' plots for all the models
% are displayed and the PAUSE between models is also enabled!
user_info = mdlsExplFig();
if isempty(user_info)
    error = [error, {'ERROR: EEMlab:mdlsExpl:userSelectedCancel'}];
    return;
else
    tic;
    data = outliertest(data,user_info.wavestep,user_info.myfactors, ...
        user_info.constraints,user_info.CC,user_info.stepwise);
    etime = datestr(toc/(24*60*60),'HH:MM:SS');
end
% if finishes OK, delete the MATLAB temporal file
if exist(fullfile(pwd,'temp.mat'),'file') == 2
    delete(fullfile(pwd,'temp.mat'));
end

% generating the model 'names' for further processing
if ~isfield(data,'modelNames')
    for i = 1 : length(user_info.myfactors)
        data.modelNames{i,1} = ['Model' num2str(user_info.myfactors(i)) ' (exploratory)'];
    end
else
    for i = 1 : length(user_info.myfactors)
        if any(~cellfun(@isempty,(strfind(data.modelNames,['Model' num2str(user_info.myfactors(i)) ' (refined']))))
            data.modelNames{~cellfun(@isempty,(strfind(data.modelNames,['Model' num2str(user_info.myfactors(i)) ' (refined'])))} = ...
                ['Model' num2str(user_info.myfactors(i)) ' (exploratory)'];
        elseif ~any(~cellfun(@isempty,(strfind(data.modelNames,['Model' num2str(user_info.myfactors(i)) ' (exploratory)']))))
            data.modelNames = [data.modelNames; {['Model' num2str(user_info.myfactors(i)) ' (exploratory)']}];
        end
    end
end

%% === UPDATE DATASET
newdata = data;

end