function [ newdata, etime, error ] = mdlsRef( data )
%
% This uses the drEEM's RANDINITANAL script to refine models
%ETIME is the elapsed time on processing the model, in string format

%% === INIT
newdata = data;
etime = '';
error = {};

% === INFO
label = 'Refine models';
info = strcat({ ...
    'Run PARAFAC multiple times to identify the least squares solution', ...
    'New models are initialised with random values', ...
    'This processing uses the drEEM''s RANDINITANAL script', ...
    'Type HELP RANDINITANAL in MATLAB''s console for more info'
    });
uiwait(msgbox(info,label,'modal'));

%% === ERROR CHECKING
if ~isfield(data,'modelNames') || isempty(data.modelNames(~cellfun(@isempty,strfind(data.modelNames,'exploratory'))))
    info = strcat({ ...
        'There are NO exploratory models to refine', ...
        'Please create an exploratory model first', ...
        });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [error, {'ERROR: EEMlab:mdlsRef:noModelsToProcess'}];
    return;    
end

%% === DATA LOAD
user_info = mdlsRefFig(data);
if isempty(user_info)
    error = [error, {'ERROR: EEMlab:mdlsRef:userSelectedCancel'}];
    return;
else
    % model: refined best Least Squares model chosen from all model runs
    % convg: Summary of convergence results for each run
    % DSit: New data structure containing iterated models
    ncomp =  num2str(user_info.f);
    tic;
    eval(['[data' ',convg' ncomp ',DSit' ncomp, ...
        '] = randinitanal(data,user_info.f,user_info.it,', ...
        'user_info.constraints,user_info.convgcrit);']);
    etime = datestr(toc/(24*60*60),'HH:MM:SS');
end
% if finishes OK, delete the MATLAB temporal file
if exist(fullfile(pwd,'temp.mat'),'file') == 2
    delete(fullfile(pwd,'temp.mat'));
end

%% === UPDATE DATASET
data.modelNames{~cellfun(@isempty,(strfind(data.modelNames,user_info.smodel)))} = ...
    ['Model' ncomp ' (refined - to validate)'];
eval(['data.convg'  ncomp ' = convg'  ncomp ';']);
eval(['data.DSit'  ncomp ' = DSit'  ncomp ';';]);
newdata = data;

end