function [ newdata, etime, error ] = mdlsSha( data )
%
% This uses the drEEM's SPLITANALYSIS script

%% === INIT
newdata = data;
etime = NaN;
error = {};

% === INFO
label = 'Split half analysis';
info = strcat({ ...
    'SHA uses the test datasets to calculate the proposed models', ...
    'The PARAFAC n-component models are stored nested in splits', ...
    'This processing uses the drEEM''s SPLITANALYSIS script', ...
    'Type HELP SPLITANALYSIS in MATLAB''s console for more info'
    });
uiwait(msgbox(info,label,'modal'));

%% === ERROR CHECKING
if ~isfield(data,'modelNames') && ...
        isempty(data.modelNames(~cellfun(@isempty,strfind(data.modelNames,'exploratory')))) && ...
        isempty(data.modelNames(~cellfun(@isempty,strfind(data.modelNames,'refined'))))
    info = strcat({ ...
        'There are NO models to validate with SHA', ...
        'Please create a model first', ...
        });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [error, {'ERROR: EEMlab:mdlsSha:noModelsToProcess'}];
    return;    
elseif ~isfield(data,'Split')
    info = strcat({ ...
        'The dataset has NOT still been splitted', ...
        'Please split in halves the dataset first', ...
        });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [error, {'ERROR: EEMlab:mdlsSha:noModelsToProcess'}];
    return;    
end

%% === DATA LOAD
% Split Half Analysis for splitted test datasets
user_info = mdlsShaFig(data);
if isempty(user_info)
    error = [error, {'ERROR: EEMlab:mdlsSha:userSelectedCancel'}];
    return;
else
    tic;
    data = splitanalysis(data,user_info.f,user_info.constraints, ...
        user_info.runs,user_info.cc);
    etime = datestr(toc/(24*60*60),'HH:MM:SS');
    if isfield(data.Split,'modelNames')
        data.Split = rmfield(data.Split,'modelNames');
    end
end
% if finishes OK, delete the MATLAB temporal file
if exist(fullfile(pwd,'temp.mat'),'file') == 2
    delete(fullfile(pwd,'temp.mat'));
end

%% === UPDATE DATASET
if any(~cellfun(@isempty,(strfind(data.modelNames,['Model' num2str(user_info.f) ' (splitted']))))
    data.modelNames{~cellfun(@isempty,(strfind(data.modelNames,['Model' num2str(user_info.f) ' (splitted'])))} = ...
        ['Model' num2str(user_info.f) ' (splitted - to validate)'];
else
    data.modelNames = ...
        [data.modelNames; {['Model' num2str(user_info.f) ' (splitted - to validate)']}];
end

newdata = data;

end