function [ newdata, error ] = mdlsSplitDs( data )
%
% This uses the drEEM's SPLITDS script

%% === INIT
newdata = data;
error = {};

% === INFO
label = 'Split dataset';
info = strcat({ ...
    'Split the original dataset to create new test datasets', ...
    'This processing uses the drEEM''s SPLITDS script', ...
    'Type HELP SPLITDS in MATLAB''s console for more info'
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
% first at all we delete OLD splits
datafields = fieldnames(data);
ind = ~cellfun(@isempty,regexp(datafields,'Split')); %model indexes
fields_to_delete = datafields(ind);
data = rmfield(data,fields_to_delete);
% now we delete all OLD validations (as the splits are gonig to change)
datafields = fieldnames(data);
ind = ~cellfun(@isempty,regexp(datafields,'Val')); %model indexes
fields_to_delete = datafields(ind);
data = rmfield(data,fields_to_delete);
% finally we update the modelNames field in the data struct
if any(~cellfun(@isempty,(strfind(data.modelNames,'splitted'))))
    data.modelNames(~cellfun('isempty',(strfind(data.modelNames,'splitted')))) = [];
end
if any(~cellfun(@isempty,(strfind(data.modelNames,'NOT VALID'))))
    NOT_VALID_str = cell(size(data.modelNames)); NOT_VALID_str(:)={'NOT VALID'};
    to_validate_str = cell(size(data.modelNames)); to_validate_str(:)={'to validate'};
    data.modelNames = cellfun(@strrep,data.modelNames,NOT_VALID_str,to_validate_str,'UniformOutput',false);
end
if any(~cellfun(@isempty,(strfind(data.modelNames,'VALID'))))
    VALID_str = cell(size(data.modelNames)); VALID_str(:)={'VALID'};
    to_validate_str = cell(size(data.modelNames)); to_validate_str(:)={'to validate'};
    data.modelNames = cellfun(@strrep,data.modelNames,VALID_str,to_validate_str,'UniformOutput',false);
end

% Subdatasets creation & Split Half Analysis for those subdatasets
user_info = mdlsSplitDsFig();
if isempty(user_info)
    error = [error, {'ERROR: EEMlab:mdlsSplitDs:userSelectedCancel'}];
    return;
else
    data = splitds(data,[],user_info.numsplit,user_info.stype,user_info.scomb);
end
label = 'Split dataset';
info = strcat({ ...
    ['The dataset is splitted in ' num2str(data.Split_NumBeforeCombine) ' splits'], ...
    ['The splits are combined into ' num2str(data.Split_NumAfterCombine) ' different halves'], ...
    ['Number of samples per halve: ' num2str(data.Split_nSample)], ...
    'Type HELP SPLITDS in MATLAB''s console for more info'
    });
uiwait(msgbox(info,label,'modal'));
%% === UPDATE DATASET
newdata = data;

end