function [ error ] = pltDsetColl( data )
% PLTDSETCOLL Uses the EEMVIEW utility from drEEM toolbox

%% === INIT
error = {};

%% === ERROR CHECKING
if ~isfield(data,'X')
    info = strcat({ ...
        'The dataset is empty of samples', ...
        'Please do the loads first', ...
        });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [error, {'ERROR: EEMlab:pltDsetColl:noSamplesInDataset'}];
    return;
end

%% === INFO
label = 'Dataset collection';
info = strcat({ ...
    'Plots a dataset collection of samples', ...
    'This processing uses the drEEM''s EEMVIEW script', ...
    'Type HELP EEMVIEW in MATLAB''s console for more info'
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
dlg_title = 'Layout';
prompt = {'Rows:','Columns:'};
num_lines = 1;
def = {'3','5'};
user_info = inputdlg(prompt,dlg_title,num_lines,def);
if isempty(user_info)
    error = [error, {'ERROR: EEMlab:pltDsetColl:userSelectedCancel'}];
    return;
end
plotlayout = [str2double(user_info{1}) str2double(user_info{2})];

% % tag selection
% stag = [];
% if isfield(data,'tagNames')
%     tags = data.tagNames;
%     name = 'Tag the samples';
%     [selected,ok] = listdlg('Name',name,...
%         'PromptString','Tag the samples:',...
%         'SelectionMode','single',...
%         'ListSize',[160 100],...
%         'ListString',tags);
%     if ~ok
%         error = [error, {'ERROR: EEMlab:pltDsetColl:userSelectedCancel'}];
%         return;
%     else
%         stag = tags{selected};
%     end
% end

%% === PLOTS
eemview(data,'X',plotlayout,[],[],'longID');
%eemview(data,'X',plotlayout,[],[],stag);


%% === UPDATE DATASET

end