function [ error ] = pltDsetEem( data, sample, dim, eemhdl, exhdl, emhdl )
%
% DIM       '2D' or '3D' plots
% EEMHDL    axes handle in where to plot the EEM
% EXHDL     axes handle in where to plot the Ex scan
% EMHDL     axes handle in where to plot the Em scan

%% === INIT
error = {};

%% === INFO
% label = 'EEM';
% info = strcat({ ...
%     'Plots the intensity values for the selected EEM sample', ...
%     });
% uiwait(msgbox(info,label,'modal'));
%% === ERROR CHECKING
% if we delete outliers and are located in the last sample before deleting!
if sample > data.nSample
    sample = data.nSample;
end

%% === DATA LOAD
emAxe = round(data.Em); % rows -- values rounded to integer to avoid axes error with float wavelenghts
exAxe = round(data.Ex); % cols -- values rounded to integer to avoid axes error with float wavelenghts
intValues = reshape(data.X(sample,:,:),[data.nEm data.nEx]);
intUnits = data.IntensityUnit;

% selecting point to the MAX intensity value
[ex,em,~,~] = getFeature(exAxe,emAxe,intValues,'maximum');
spoint = [ex em];   % SPOINT(1) is the excitation wavelength for the selected point
                    % SPOINT(2) is the emission wavelength for the selected point

%% === PLOT
% plot EEM intensity values on EEMHDL axes handles
[~,err] = plotEem(exAxe,emAxe,intValues,intUnits,dim,spoint,eemhdl);
error = [error, err];
% plot the Ex scan on EXHDL axes handles
[~,err] = plotExScan(exAxe,emAxe,intValues,intUnits,spoint(2),exhdl);
error = [error, err];
% plot the Em scan on EMHDL axes handles
[~,err] = plotEmScan(exAxe,emAxe,intValues,intUnits,spoint(1),emhdl);
view(emhdl,90,-90); % swaps X and Y axis
error = [error, err];

end