function [error] = pltDsetInfo( data, sample, infhdl  )
%
% INFHDL    axes handle in where to display the information

%% === INIT
error = {};

%% === INFO
% label = 'EEM information';
% info = strcat({ ...
%     'Displays the full information for the selected EEM sample', ...
%     });
% uiwait(msgbox(info,label,'modal'));

%% === ERROR CHECKING
% if we delete outliers and are located in the last sample before deleting!
if sample > data.nSample
    sample = data.nSample;
end

%% === DATA LOAD
% EEM file name
fileName = data.filelist(sample);
% EEM tags
tagNames = '';
tagValues = '';
if isfield(data,'tagNames')
    tagNames = data.tagNames;
    tagValues = cell(length(tagNames),1);
    for i = 1 : length(tagNames)
        value = data.(tagNames{i})(sample);
        if isnumeric(value)
            tagValues{i} = num2str(value);
        else
            tagValues(i) = value;
        end
    end
end

nSamp = data.nSample;
emAxe = data.Em; % rows
exAxe = data.Ex; % cols
intValues = reshape(data.X(sample,:,:),[data.nEm data.nEx]);
intUnits = data.IntensityUnit;

% EEM feature extraction
feaNames = '';
feaValues = '';
feaUnits = '';

[ex,em,maxint,~] = getFeature(exAxe,emAxe,intValues,'maximum');
feaNames{end+1,1} = 'Maximum intensity value';
feaValues{end+1,1} = maxint;
feaUnits{end+1,1} = intUnits;
feaNames{end+1,1} = 'Excitation wavelength at maximum';
feaValues{end+1,1} = ex;
feaUnits{end+1,1} = 'nm';
feaNames{end+1,1} = 'Emission wavelength at maximum';
feaValues{end+1,1} = em;
feaUnits{end+1,1} = 'nm';

[ex,~,sstate,~] = getFeature(exAxe,emAxe,intValues,'singlet');
feaNames{end+1,1} = 'Intensity at singlet state';
feaValues{end+1,1} = sstate;
feaUnits{end+1,1} = intUnits;
feaNames{end+1,1} = 'Ex/Em wavelength at singlet state';
feaValues{end+1,1} = ex;
feaUnits{end+1,1} = 'nm';

%% === PLOT
dispInfo(sample,nSamp,tagNames,tagValues,feaNames,feaValues,feaUnits,infhdl);

end