function [ error ] = pltDsetScatt( data )
%

%% === INIT
error = {};

%% === INFO
label = 'Feature scatt';
info = strcat({ ...
    'Scattering plot of featutes', ...
    'Please select just TWO features to plot', ...
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
nSamp = data.nSample;
emAxe = data.Em; % rows
exAxe = data.Ex; % cols
value1 = NaN(1,nSamp);
value2 =  NaN(1,nSamp);

% FEATURES
feats = {'maximum intensity', ...
    'singlet state', ...
    'stokes distance'};
units = {['intensity (' data.IntensityUnit ')'], ...
    'wavelength (nm)', ...
    'distance (nm)'};
name = 'Feature selection';
[selected,ok] = listdlg('Name',name,...
    'PromptString','Select 2 features to plot:',...
    'SelectionMode','multiple',...
    'ListSize',[160 100],...
    'ListString',feats);
if ~ok
    error = [error, ...
        {'ERROR: EEMlab:pltDsetScatt:userSelectedCancel'}];
    return;
elseif length(selected) ~= 2
    label = 'Feature scatt';
    info = strcat({ ...
        'Scattering plot of featutes', ...
        'You have selected more than TWO features to plot', ...
        });
    uiwait(errordlg(info,label,'modal'));
    error = [error, ...
        {'ERROR: EEMlab:pltDsetScatt:wrongNumberOfFSelectedFeatures'}];
    return;
else
    for i = 1 : nSamp
        intValues = reshape(data.X(i,:,:),[data.nEm data.nEx]);
        for j = 1 : 2
            switch selected(j)
                case 1 % maximum intensity
                    [~,~,value,~] = getFeature(exAxe,emAxe,intValues,'maximum');
                case 2 % singlet state
                    [value,~,~,~] = getFeature(exAxe,emAxe,intValues,'singlet');
                case 3 % Stokes distance
                    [value,~,~,~] = getFeature(exAxe,emAxe,intValues,'stokes');
            end
            eval(['value' num2str(j) '(' num2str(i) ') = ' num2str(value) ';']);
            eval(['label' num2str(j) ' = ''' units{selected(j)} ''';']);
        end
    end
end
tit = strcat(feats(selected(1)),' vs. ',feats(selected(2)));

% TAGS
if isfield(data,'tagNames')
    tags = {'--', data.tagNames{:}};
    name = 'Tag the results';
    [selected,ok] = listdlg('Name',name,...
        'PromptString','Select the tag to load:',...
        'SelectionMode','single',...
        'ListSize',[160 100],...
        'ListString',tags);
    if ~ok
        error = [error, ...
            {'ERROR: EEMlab:pltDsetScatt:userSelectedCancel'}];
        return;
    else
        stag = tags{selected};
        if strcmp(stag,'--')
            tags = '';
        else
            maxItemsAllowed = 50;
            if length(unique(data.(stag))) > maxItemsAllowed
                info = strcat({ ...
                    ['The number of different tags allowed is ' num2str(maxItemsAllowed)], ...
                    ['There are ' num2str(length(unique(data.(stag)))) ' different tags in this plot'], ...
                    });
                label = 'Error';
                icon = 'error';
                uiwait(msgbox(info,label,icon,'modal'));
                error = [error, ...
                    {'ERROR: EEMlab:pltDsetScatt:tooManyTagsInSelection'}];
                return;
            else
                tags = data.(stag);
            end
        end
    end
else
    info = strcat({ ...
        'No tags are loaded in the dataset', ...
        'Please load tags', ...
        });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [error, ...
        {'ERROR: EEMlab:pltDsetScatt:noTagsLoaded'}];
    return;
end

%% === PLOTS
ssamp = [];
[~,~] = plotScatt(value1,label1,value2,label2,tags,ssamp,tit);

%% === UPDATE DATASET

end