function [ error ] = pltMdlCompCorr( data )
%

%% === INIT
error = {};

%% === ERROR CHECKING
if ~isfield(data,'modelNames') || isempty(data.modelNames)
    info = strcat({ ...
        'The dataset has not been still modeled', ...
        'Please create exploratory, refined or splitted models first', ...
        });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [error, {'ERROR: EEMlab:pltMdlCompcorr:noModelsToProcess'}];
    return;
end

%% === INFO
label = 'Correlations';
info = strcat({ ...
    'This processing uses the drEEM''s COMPCORRPLOT script', ...
    'COMPCORRPLOT plots correlations between the concentrations of components for the estimated model', ...
    'Type HELP COMPCORRPLOT in MATLAB''s console for more info'
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
name = 'Correlations between components';
models = data.modelNames;
[selected,ok] = listdlg('Name',name,...
    'PromptString','Select a model', ...
    'SelectionMode','single',...
    'ListSize',[180 180],...
    'ListString',models);
if ~ok
    error = [error, {'ERROR: EEMlab:pltMdlCompcorr:userSelectedCancel'}];
    return;
end
smodel = models{selected};
tok = strtok(smodel,'Model');
myfactors = str2double(tok(1));

% now we load the SHA split to plot (Name of the halves)
if strfind(smodel,'splitted')
    names = [{'A'},{'B'},{'C'},{'D'},{'E'},{'F'},{'G'},{'H'},{'I'}, ...
        {'J'},{'K'},{'L'},{'M'},{'N'},{'O'},{'P'},{'Q'},{'R'},{'S'},{'T'},{'U'}, ...
        {'V'},{'W'},{'X'},{'Y'},{'Z'}];
    splitnames = cell(1,data.Split_NumAfterCombine);
    for i = 1 : data.Split_NumAfterCombine
        splitnames{i} = ['[' strjoin(names(str2num(data.Split_Combinations{i}))) ']'];
    end
    name = 'Select the splits (SHA halves)';
    [ssplit,ok] = listdlg('Name',name,...
        'PromptString','Select the dataset split', ...
        'SelectionMode','single',...
        'ListSize',[100 100],...
        'ListString',splitnames);
    if ~ok
        error = [error, {'ERROR: EEMlab:pltMdlCompcorr:userSelectedCancel'}];
        return;
    end
end

% if we want to plot tags
stag = [];
if isfield(data,'tagNames')
    tags = [{'--'}, data.tagNames{:}];
    name = 'Tag the results';
    [selected,ok] = listdlg('Name',name,...
        'PromptString','Select the tag to load:',...
        'SelectionMode','single',...
        'ListSize',[160 100],...
        'ListString',tags);
    if ~ok
        error = [error, {'ERROR: EEMlab:pltMdlCompcorr:userSelectedCancel'}];
        return;
    else
        stag = tags{selected};
        if strcmp(stag,'--')
            stag = [];
        else
            maxItemsAllowed = 50;
            if length(unique(data.(stag))) > maxItemsAllowed
                info = strcat({ ...
                    'The maximum number of different tags is 50', ...
                    ['There are ' num2str(length(stag)) ' different tags in this plot'], ...
                    'Please repeat the plot with another tag', ...
                    });
                label = 'Error';
                icon = 'error';
                uiwait(msgbox(info,label,icon,'modal'));
                error = [error, {'ERROR: EEMlab:pltMdlCompcorr:tooManyTagsInSelection'}];
                return;
            end
        end
    end
end

%% === PLOTS
if strfind(smodel,'exploratory')
    compcorrplot(data,myfactors,[],stag);
    set(gcf, 'NumberTitle','off', 'Name',[smodel ' - correlations between components']);
elseif strfind(smodel,'refined')
    compcorrplot(data,myfactors,[],stag);
    set(gcf, 'NumberTitle','off', 'Name',[smodel ' - correlations between components']);
elseif strfind(smodel,'splitted')
    compcorrplot(data.Split(ssplit),myfactors,[],stag);
    set(gcf, 'NumberTitle','off', 'Name',[smodel ' - correlations between components']);
end

%% === UPDATE DATASET

end