function [ error ] = pltMdlEres1( data )
%

%% === INIT
error = {};

%% === ERROR CHECKING
if ~isfield(data,'modelNames') || isempty(data.modelNames)
    info = strcat({ ...
        'The dataset has not been still modeled', ...
        'Please create exploratory, refined or splitted models first', ...
        });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [error, {'ERROR: EEMlab:pltMdlEres1:noModelsToProcess'}];
    return;
end

%% === INFO
label = 'Error residuals';
info = strcat({ ...
    'Plots the sample error residuals against the selected model', ...
    'This processing uses the drEEM''s EEMVIEW script', ...
    'Type HELP EEMVIEW in MATLAB''s console for more info'
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
name = 'Error residuals - ONE model';
models = data.modelNames;
[selected,ok] = listdlg('Name',name,...
    'PromptString','Select ONE model', ...
    'SelectionMode','single',...
    'ListSize',[180 180],...
    'ListString',models);
if ~ok
    error = [error, {'ERROR: EEMlab:pltMdlEres1:userSelectedCancel'}];
    return;
end
smodel = models{selected};
tok = strtok(smodel,'Model');
myfactors = str2double(tok(1));

% now we load the SHA split to plot (Name of the halves)
if strfind(smodel,'splitted')
    names = [{'A'},{'B'},{'C'},{'D'},{'E'},{'F'},{'G'},{'H'},{'I'}, ...
        {'J'},{'K'},{'L'},{'M'},{'N'},{'O'},{'P'},{'Q'},{'R'},{'S'},{'T'},{'U'}, ...
        {'V'},{'W'},{'X'},{'Y'},{'Z'}];
    splitnames = cell(1,data.Split_NumAfterCombine);
    for i = 1 : data.Split_NumAfterCombine
        splitnames{i} = ['[' strjoin(names(str2num(data.Split_Combinations{i}))) ']'];
    end
    name = 'Select the splits (SHA halves)';
    [ssplit,ok] = listdlg('Name',name,...
        'PromptString','Select the dataset split', ...
        'SelectionMode','single',...
        'ListSize',[100 100],...
        'ListString',splitnames);
    if ~ok
        error = [error, {'ERROR: EEMlab:pltMdlSpecLod:userSelectedCancel'}];
        return;
    end
end

%% === PLOTS
datafield = {'X',['Model' num2str(myfactors)],'error_residuals'};
plotlayout = [4 3];
istart = 1;
plotview = [];
datalabel = {'sample','modeled sample','error for sample'};
axeslimits = [1 1 0.1];
rotate = [];
colorbar = 'colorbar';
ncontours = [];
plotsize = [];
if strfind(smodel,'exploratory')
    eemview({data,data},datafield,plotlayout,istart, ...
        plotview,datalabel,axeslimits,rotate, ...
        colorbar,ncontours,plotsize);
    set(gcf, 'NumberTitle','off', 'Name',[smodel ' - error residuals']);
elseif strfind(smodel,'refined')
    eemview({data,data},datafield,plotlayout,istart, ...
        plotview,datalabel,axeslimits,rotate, ...
        colorbar,ncontours,plotsize);
    set(gcf, 'NumberTitle','off', 'Name',[smodel ' - error residuals']);
elseif strfind(smodel,'splitted')
    eemview({data.Split(ssplit),data.Split(ssplit)},datafield,plotlayout,istart, ...
        plotview,datalabel,axeslimits,rotate, ...
        colorbar,ncontours,plotsize);
    set(gcf, 'NumberTitle','off', 'Name',[smodel ' - error residuals']);
end

%% === UPDATE DATASET

end