function [ error ] = pltMdlFprints( data )
% PLTMDLFPRINT displays the fingerprints for the selected model

%% === INIT
error = {};

%% === ERROR CHECKING
if ~isfield(data,'modelNames') || isempty(data.modelNames)
    info = strcat({ ...
        'The dataset has not been still modeled', ...
        'Please create the exploratory, refined or splitted models first', ...
        });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [error, {'ERROR: EEMlab:pltMdlFprints:noModelsToProcess'}];
    return;
end

%% === INFO
label = 'Plot fingerprints';
info = strcat({ ...
    'Displays the fingerprints for the selected model', ...
    'This processing uses the drEEM''s FINGERPRINT script', ...
    'Type HELP FINGERPRINT in MATLAB''s console for more info'
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
name = 'Plot fingerprints';
models = data.modelNames;
[selected,ok] = listdlg('Name',name,...
    'PromptString','Select a model', ...
    'SelectionMode','single',...
    'ListSize',[180 180],...
    'ListString',models);
if ~ok
    error = [error, {'ERROR: EEMlab:pltMdlFprints:userSelectedCancel'}];
    return;
end
smodel = models{selected};
tok = strtok(smodel,'Model');
myfactors = str2double(tok(1));

% now we load the SHA split to plot (Name of the halves)
if strfind(smodel,'splitted')
    names = [{'A'},{'B'},{'C'},{'D'},{'E'},{'F'},{'G'},{'H'},{'I'}, ...
        {'J'},{'K'},{'L'},{'M'},{'N'},{'O'},{'P'},{'Q'},{'R'},{'S'},{'T'},{'U'}, ...
        {'V'},{'W'},{'X'},{'Y'},{'Z'}];
    splitnames = cell(1,data.Split_NumAfterCombine);
    for i = 1 : data.Split_NumAfterCombine
        splitnames{i} = ['[' strjoin(names(str2num(data.Split_Combinations{i}))) ']'];
    end
    name = 'Select the splits (SHA halves)';
    [ssplit,ok] = listdlg('Name',name,...
        'PromptString','Select the SHA halves to compare', ...
        'SelectionMode','single',...
        'ListSize',[100 100],...
        'ListString',splitnames);
    if ~ok
        error = [error, {'ERROR: EEMlab:pltMdlCompcorr:userSelectedCancel'}];
        return;
    end
end

%% === PLOTS
if strfind(smodel,'exploratory')
    fingerprnt(data,myfactors);
    set(gcf, 'NumberTitle','off', 'Name',[smodel ' - Fingerprints']);
elseif strfind(smodel,'refined')
    fingerprnt(data,myfactors);
    set(gcf, 'NumberTitle','off', 'Name',[smodel ' - Fingerprints']);
elseif strfind(smodel,'splitted')
    fingerprnt(data.Split(ssplit),myfactors);
    set(gcf, 'NumberTitle','off', 'Name',[smodel ' - Fingerprints']);
end

%% === UPDATE DATASET

end