function [ error ] = pltMdlLodLev( data )
%

%% === INIT
error = {};

%% === ERROR CHECKING
if ~isfield(data,'modelNames') || isempty(data.modelNames)
    info = strcat({ ...
         'The dataset has not been still modeled', ...
        'Please create exploratory, refined or splitted models first', ...
       });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [error, {'ERROR: EEMlab:pltMdlLodLev:noModelsToProcess'}];
    return;
end

%% === INFO
label = 'Loadings & leverages';
info = strcat({ ...
    'Identify samples or wavelengths with high influence on the models', ...
    'This processing uses the drEEM''s LOADINGSANDLEVERAGES script', ...
    'Type HELP LOADINGSANDLEVERAGES in MATLAB''s console for more info'
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
name = 'Correlations between components';
models = data.modelNames;
[selected,ok] = listdlg('Name',name,...
    'PromptString','Select ONE model', ...
    'SelectionMode','single',...
    'ListSize',[180 180],...
    'ListString',models);
if ~ok
    error = [error, {'ERROR: EEMlab:pltMdlLodLev:userSelectedCancel'}];
    return;
end
smodel = models{selected};
tok = strtok(smodel,'Model');
myfactors = str2double(tok(1));

% now we load the splitted models to plot (Name of the halves)
if strfind(smodel,'splitted')
    names = [{'A'},{'B'},{'C'},{'D'},{'E'},{'F'},{'G'},{'H'},{'I'}, ...
        {'J'},{'K'},{'L'},{'M'},{'N'},{'O'},{'P'},{'Q'},{'R'},{'S'},{'T'},{'U'}, ...
        {'V'},{'W'},{'X'},{'Y'},{'Z'}];
    splitnames = cell(1,data.Split_NumAfterCombine);
    for i = 1 : data.Split_NumAfterCombine
        splitnames{i} = ['[' strjoin(names(str2num(data.Split_Combinations{i}))) ']'];
    end
    name = 'Select the dataset split';
    [ssplit,ok] = listdlg('Name',name,...
        'PromptString','Select the SHA halves to compare', ...
        'SelectionMode','single',...
        'ListSize',[100 100],...
        'ListString',splitnames);
    if ~ok
        error = [error, {'ERROR: EEMlab:pltMdlSpecLod:userSelectedCancel'}];
        return;
    end
end

%% === PLOTS
if strfind(smodel,'exploratory')
    loadingsandleverages(data,myfactors);
    set(gcf, 'NumberTitle','off', 'Name',[smodel ' - scores, leverage & loadings']);
elseif strfind(smodel,'refined')
    loadingsandleverages(data,myfactors);
    set(gcf, 'NumberTitle','off', 'Name',[smodel ' - scores, leverage & loadings']);
elseif strfind(smodel,'splitted')
    loadingsandleverages(data.Split(ssplit),myfactors);
    set(gcf, 'NumberTitle','off', 'Name',[smodel ' (' splitnames{ssplit} ' split)' ' - scores, leverage & loadings']);
end

%% === UPDATE DATASET

end