function [ error ] = pltMdlLsSseCc( data )
%
%PLTMDLLSSSECC plots the global Sum of Squared Errors & Core Consistency
%for ReFined and VaLidated models (see drEEM's toolbox RANDINITANAL script)

%% === INIT
error = {};

%% === ERROR CHECKING
if ~isfield(data,'modelNames') || isempty(data.modelNames) || isempty(data.modelNames(~cellfun(@isempty,strfind(data.modelNames,'refined'))))
    info = strcat({ ...
        'The dataset has not been still modeled', ...
        'or models have NOT been refined', ...
        'Please create a refined model first', ...
        });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [error, {'ERROR: EEMlab:pltMdlLsSseCc:noModelsToProcess'}];
    return;
end

%% === INFO
label = 'Global SSE & Core Consistency';
info = strcat({ ...
    'plots the global Sum of Squared Errors & Core Consistency', ...
    'for ReFined (RF) and VaLidated (VL) models', ...
    'This processing uses the drEEM''s RANDINITANAL script', ...
    'Type HELP RANDINITANAL in MATLAB''s console for more info'
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
name = 'Global SSE & Core Consistency';
% ONLY refined models for this processing
models = data.modelNames(~cellfun(@isempty,strfind(data.modelNames,'refined')));
[selected,ok] = listdlg('Name',name,...
    'PromptString','Select a model', ...
    'SelectionMode','single',...
    'ListSize',[180 180],...
    'ListString',models);
if ~ok
    error = [error, {'ERROR: EEMlab:pltMdlLsSseCc:userSelectedCancel'}];
    return;
end
smodel = models{selected};
tok = strtok(smodel,'Model');
myfactors = str2double(tok(1));

%% === PLOTS
    eval(['values = data.DSit' num2str(myfactors) ';']);
    eval(['it = size(data.convg' num2str(myfactors) ',1);']); % IT is the number of models tested
    constraints = 'existing';
    randinitanal(values,myfactors,it,constraints);

%% === UPDATE DATASET

end