function [ error ] = pltMdlSpecSse( data )
%

%% === INIT
error = {};

%% === ERROR CHECKING
if ~isfield(data,'modelNames') || isempty(data.modelNames)
    info = strcat({ ...
        'The dataset has not been still modeled', ...
        'Please create the, refined or splitted models first', ...
        });
    label = 'Error';
    icon = 'error';
    uiwait(msgbox(info,label,icon,'modal'));
    error = [error, {'ERROR: EEMlab:pltMdlSpecSse:noModelsToProcess'}];
    return;
end

%% === INFO
label = 'Spectral SSE';
info = strcat({ ...
    'This processing uses the drEEM''s SPECSSE script', ...
    'SPECSSE plots the Sum of Squared Errors of the', ...
    'Ex/Em spectrums for the selected models', ...
    'Type HELP SPECSSE in MATLAB''s console for more info'
    });
uiwait(msgbox(info,label,'modal'));

%% === DATA LOAD
name = 'Spectral SSE';
models = data.modelNames;
[selected,ok] = listdlg('Name',name,...
    'PromptString','Select the models to compare', ...
    'SelectionMode','multiple',...
    'ListSize',[180 180],...
    'ListString',models);
if ~ok
    error = [error, {'ERROR: EEMlab:pltMdlSpecSse:userSelectedCancel'}];
    return;
end
smodels = models(selected);
myfactors = nan(1,length(smodels));
EXlist = false(length(smodels),1); % list of Exploratory (OUTLIERTEST) models
RFlist = false(length(smodels),1); % list Refined (RANDINITANAL) models
SPlist = false(length(smodels),1); % list Validated (SPLITDS, SPLITANALYSIS, SPLITVALIDATION) models
for i = 1 : length(smodels)
    tok = strtok(smodels{i},'Model');
    myfactors(i) = str2double(tok(1));
    if strfind(smodels{i},'exploratory')
        EXlist(i,1) = true;
    elseif strfind(smodels{i},'refined')
        RFlist(i,1) = true;
    elseif strfind(smodels{i},'splitted')
        SPlist(i,1) = true;
    end
end
% now we load the SHA split to plot (Name of the halves)
if any(SPlist)
    names = [{'A'},{'B'},{'C'},{'D'},{'E'},{'F'},{'G'},{'H'},{'I'}, ...
        {'J'},{'K'},{'L'},{'M'},{'N'},{'O'},{'P'},{'Q'},{'R'},{'S'},{'T'},{'U'}, ...
        {'V'},{'W'},{'X'},{'Y'},{'Z'}];
    splitnames = cell(1,data.Split_NumAfterCombine);
    for i = 1 : data.Split_NumAfterCombine
        splitnames{i} = ['[' strjoin(names(str2num(data.Split_Combinations{i}))) ']'];
    end
    name = 'Select the split (SHA half)';
    [ssplit,ok] = listdlg('Name',name,...
        'PromptString','Select the dataset split', ...
        'SelectionMode','single',...
        'ListSize',[100 100],...
        'ListString',splitnames);
    if ~ok
        error = [error, {'ERROR: EEMlab:pltMdlSpecLod:userSelectedCancel'}];
        return;
    end
end

%% === PLOTS
if any(EXlist|RFlist)
    factors = myfactors(EXlist|RFlist);
    specsse(data,factors);
    set(gcf, 'NumberTitle','off', ...
        'Name',['Exploratory & Refined models - Sum of Squared Error for ' num2str(factors) ' components']);
end
if any(SPlist)
    factors = myfactors(SPlist);
    specsse(data.Split(ssplit),factors);
    set(gcf, 'NumberTitle','off', ...
        'Name',['Splitted models - Sum of Squared Error for ' num2str(factors) ' components']);
end

%% === UPDATE DATASET

end