function [ newhandles ] = appConfig( handles, description )
%APPCONFIG is the script to configure the EEMlab HANDLES
%DESCRIPTION is a txt file with the version number, features and details of
%the implemented version

newhandles = handles;

%% == HARDWARE config
if ismac
    % Code to run on Mac platform
    delimiter = '/';
    config.datadir = strcat('/Users/',getenv('USER'),'/Documents'); % datadir (HOME) configuration
    % if ~exist(config.datadir,'dir')
    %     mkdir(config.datadir);
    % end
elseif isunix
    % Code to run on Linux platform
    delimiter = '/';
elseif ispc
    % Code to run on Windows platform
    delimiter = '\';
    config.datadir = strcat(getenv('USERPROFILE'),'\Documents');    % datadir (HOME) configuration
    % if ~exist(config.datadir,'dir')
    %     mkdir(config.datadir);
    % end
    if opengl('INFO')
        opengl('save','software'); % switches to OpenGL functions to plot graps
        %warning('off');
    end
else
    disp('Platform not supported')
end

%% == MATLAB config
clc;
warning('off', 'MATLAB:appConfig:warningOff');
%disp('===> MATLAB Config... adding all MATLAB directories to the path');
addpath(genpath(pwd));
%disp('===> MATLAB Config... saving new directories to the path');
savepath;
%disp('===> MATLAB Config... the new environment is properly configured');
warning('on', 'MATLAB:appConfig:warningOn');
clc;

%% === APPLICATION config
config.screenunits = 'pixels';
set(0,'units',config.screenunits); % setting to pixels the main screen size
config.screensize = get(0,'screensize'); % (x_min, y_min) (x_max y_max) in pixels
appwidth = 725; appheight = 585;
config.appsize = [appwidth appheight];
config.appunits = 'pixels';
%config.appposition  = [config.screensize(1) ...
%    config.screensize(4)-config.appsize(2) ...
%    config.appsize];
config.appposition = handles.EEMlab.Position;
app = which(mfilename);
ind = find(app == delimiter);
config.rootdir = app(1:ind(end-2)-1); % installation directory

[text, ~] = txtfile2cellarray(description);
[var,val] = strtok(text{1});
if strcmp(var,'APP_NAME')
    config.appname = strtrim(val);
else
    config.appname = '';
end
[var,val] = strtok(text{2});
if strcmp(var,'MAJOR_RELEASE')
    major = strtrim(val);
else
    major = '?';
end
[var,val] = strtok(text{3});
if strcmp(var,'MINOR_RELEASE')
    minor = strtrim(val);
else
    minor = '?';
end
[var,val] = strtok(text{4});
if strcmp(var,'MANTEINANCE')
    mant = strtrim(val);
else
    mant = '?';
end
config.appversion = ['v' major minor mant]; % version of the app
[var,val] = strtok(text{5}); % last date when EEMlab was used in order to implement automatic updates
if strcmp(var,'LAST_DATE')
    config.lastdate = strtrim(val);
else
    config.lastdate = date;
end
[var,val] = strtok(text{6}); % last date when EEMlab was used in order to implement automatic updates
if strcmp(var,'RELEASE_DATE')
    config.releasedate = strtrim(val);
else
    config.releasedate = '-';
end
config.appfeatures = {};
for i = 7 : length(text)
    [var,val] = strtok(text{i});
    if strcmp(var,'FEATURE')
        config.appfeatures{end+1} = strtrim(val);
    else
        config.appfeatures{end+1} = '';
    end
end

% updating DESCRIPTION file with LASTDATE
text{5} = ['LAST_DATE' '\t' date];
if exist(fullfile(config.rootdir,'\',description),'file') == 2
    cellarray2txtfile(text,fullfile(config.rootdir,'\',description));
end

% log configuration
config.log = { ...
    ['-->' config.appname ':Configuration'], ...
    ['Date: ' date], ...
    ['Version: ' config.appversion], ...
    ['Last access: ' config.lastdate], ...
    '', ...
    ['-->' config.appname ':Features'], ...
    ['Date: ' date], ...
    config.appfeatures{:}, ...
    };

% this is to delete the LOG file when closing the dataset
if isfield(handles,'config')
    cd(handles.config.datadir);
    log_file = strcat(handles.config.datadir,'\~log.tmp');
    if exist(log_file,'file')
        eval(['!del ' log_file]);
    end
end
cd(config.datadir);
config.outputdir = config.datadir;
newhandles.config = config;

%% === MENU config
setMenu('off',handles.eem,handles.lod,handles.dset,handles.mdls,handles.plt,handles.exp); %close all
setMenu('on',handles.eem,handles.lod_conf,handles.exp_log,handles.exp_load);
newhandles.plt_dset_2D.Checked = 'on';
newhandles.plt_dset_3D.Checked = 'off';
% =========== settings for VISIBLE=OFF menu options
% we keep the scripts but we 'hide' them at the moment
newhandles.lod_corr_spec_full.Visible = 'off';

%% === TOOLBAR config
setToolbar(newhandles,'off');
newhandles.EEMlab_ok.Visible = 'on';
newhandles.EEMlab_ok.Enable = 'on';
newhandles.EEMlab_nok.Visible = 'on';
newhandles.EEMlab_nok.Enable = 'off';

%% === GUI config
ch = findobj(gcf, 'tag','Colorbar');
delete(ch); % first find Colorbar object and delete it
newhandles.EEMlab_eem.Visible = 'off';
cla(newhandles.EEMlab_eem);
newhandles.EEMlab_ex.Visible = 'off';
cla(newhandles.EEMlab_ex);
newhandles.EEMlab_em.Visible = 'off';
cla(newhandles.EEMlab_em);
newhandles.EEMlab_info.Visible = 'off';
newhandles.EEMlab_info.String = '';
newhandles.EEMlab_slider.Visible = 'off';
newhandles.EEMlab_slider.Value = 1; % set the slider to default position
newhandles.EEMlab_info.Visible = 'off';
newhandles.EEMlab_info.String = '';

%% === DATASET config
newhandles.samplelog = []; % samplelog metadata
newhandles.loads = [];
newhandles.data = [];

end