function [ x, y, value, error ] = getFeature( xRange, yRange, vRange, feature )
%
%GETFEATURE extracts from DATA the VALUE for the selected FEATURE
%The list of FEATURE values is:
% 'maximum'	for the maximum value of the fluorescence intensity or
% 'singlet' Ex/Em wavelength and fluorescence intensity for the singlet state
%           The singlet state is where excitation and emission scans for the maximum intensity cross themselves
% 'stokes'  Stokes distance: distance (in nm) between the Ex/Em wavelengths for the maximum intensity value
% XRANGE    the values for the X-axe
% YRANGE    the values for the Y-axe
% vRANGE    the values for the matrix that matches the X & Y axes

%% === INIT
error = {};
x = NaN;
y = NaN;
value = NaN;

%% === DATA
switch feature

    case 'maximum' % maximum intensity value
            value = max(vRange(:));
            [y_ind,x_ind] = find(vRange == value);
            y = yRange(y_ind(1)); % emission wavelength for the maximum intensity
            x = xRange(x_ind(1)); % excitation wavelength for the maximum intensity

    case 'singlet' % singlet state
            maxInt = max(vRange(:));
            [y_ind,x_ind]= find(vRange == maxInt);
            cpoint = InterX([xRange'; vRange(y_ind(1),:)],[yRange'; vRange(:,x_ind(1))']);
            if ~isempty(cpoint)
                x = cpoint(1);       % wavelength for the crossing point
                y = cpoint(1);
                value = cpoint(2);	% fluorescence intensity of the crossing point
            else
                x = max(min(xRange),min(yRange));
                y = max(min(xRange),min(yRange));
                value = NaN;
            end

    case 'stokes' % Stokes distance
            maxInt = max(vRange(:));
            [y_ind,x_ind]= find(vRange == maxInt);
            y = yRange(y_ind); % emission wavelength for the maximum intensity
            x = xRange(x_ind); % excitation wavelength for the maximum intensity
            value = abs(x-y);

    otherwise
        error = [ ...
            error, ...
            {'ERROR: EEMlab:getFeature:wrongSelectedFeature'}, ...
            {'Only ''maximum intensity'' or ''singlet state'' features supported'}, ...
            ];
        return;
end
value(value <= 0) = 0;

end
