function [ hdl, error ] = plotEmScan( exAxe, emAxe, intValues, intUnits, swavelength, varargin )
%
% PLOTEMSCAN plots the excitation scan for the selected EEM intensity value
% in SWAVELENGTH
%
% EXAXE:        excitation wavelengths
% EMAXE:        emission wavelengths
% INTVALUES:    fluorescence intensity values
% INTUNITS:     fluorescence intensity units
% SWAVELENGTH   selected excitation wavelength for the emission scan
%
% HDL           handle (figure or axes) in where the plot is displayed
% ERROR         error log missage

%% INIT
error = {};

%% PARSE inputs & ERROR checking
switch nargin
    case 1,
    case 2,
    case 3,
    case 4,
        error = [error, ...
            {'ERROR: EEMlab:plotEmScan:invalidNumberOfInputArguments'}];
        return;
    case 5,
        hdl = figure('NumberTitle','off', 'Name','Emission scan for the selected sample', ...
            'WindowStyle','normal');
        datacursormode on;
    case 6,
        hdl = varargin{1}; % axes handle
        if strcmp(get(hdl,'type'),'axes')
            axes(hdl);
        else
            error = [error, ...
                {'ERROR: EEMlab:plotEmScan:invalidAxesType'}];
            return;
        end
    otherwise
        error = [error, ...
            {'ERROR: EEMlab:plotEmScan:invalidNumberOfInputArguments'}];
        return;
end

%% === DATA
% getting scan VALUES from the selected wavelength
ex_ind = exAxe == swavelength;
emInt = intValues(:,ex_ind,:); % emission scan (for the selected emission wavelength)

%% === PLOT
plot(emAxe,emInt, '-r', 'LineWidth',2);
%legend(['Em scan (' num2str(swavelength) ' nm)']);
axis([min(emAxe) max(emAxe) min(emInt) 1.1*max(emInt)]);
set(gca, 'FontSize',10, 'FontWeight','normal');
set(gca,'YTickLabel',[]); % delete ticks in Y-axe
grid on;
%title(['Emission scan at ' num2str(spoint(2)) ' nm'], 'FontSize',10, 'FontWeight','normal');
xlabel('Emission (nm)', 'FontSize',10, 'FontWeight','normal');
%ylabel(['fluorescence intensity (' intUnits ')'], 'FontSize',10, 'FontWeight','normal');

end