function [ hdl, error ] = plotExScan( exAxe, emAxe, intValues, intUnits, swavelength, varargin )
%
% PLOTEXSCAN plots the excitation scan for the selected EEM intensity value
% in EMWAVELENGTH
%
% EXAXE:        excitation wavelengths
% EMAXE:        emission wavelengths
% INTVALUES:    fluorescence intensity values
% INTUNITS:     fluorescence intensity units
% SWAVELENGTH   selected emission wavelength for the excitation scan
%
% HDL           handle (figure or axes) in where the plot is displayed
% ERROR         error log missage

%% INIT
error = {};

%% PARSE inputs & ERROR checking
switch nargin
    case 1,
    case 2,
    case 3,
    case 4,
        error = [error, ...
            {'ERROR: EEMlab:plotExScan:invalidNumberOfInputArguments'}];
        return;
    case 5,
        hdl = figure('NumberTitle','off', 'Name','Excitation scan for the selected sample', ...
            'WindowStyle','normal');
        datacursormode on;
    case 6,
        hdl = varargin{1}; % axes handle
        if strcmp(get(hdl,'type'),'axes')
            axes(hdl);
        else
            error = [error, ...
                {'ERROR: EEMlab:plotExScan:invalidAxesType'}];
            return;
        end
    otherwise
        error = [error, ...
            {'ERROR: EEMlab:plotExScan:invalidNumberOfInputArguments'}];
        return;
end

%% === DATA
% getting scan VALUES from the selected wavelength
em_ind = emAxe == swavelength;
exInt = intValues(em_ind,:)'; % excitation scan (for the selected emission wavelength)

%% === PLOT
plot(exAxe,exInt, '-r', 'LineWidth',2);
%legend(['Ex scan (' num2str(swavelength) ' nm)']);
axis([min(exAxe) max(exAxe) min(exInt) 1.1*max(exInt)]);
set(gca, 'FontSize',10, 'FontWeight','normal');
set(gca,'YTickLabel',[]); % delete ticks in Y-axe
grid on;
%title(['Excitation scan at ' num2str(spoint(2)) ' nm'], 'FontSize',10, 'FontWeight','normal');
xlabel('Excitation (nm)', 'FontSize',10, 'FontWeight','normal');
%ylabel(['fluorescence intensity (' intUnits ')'], 'FontSize',10, 'FontWeight','normal');

end