function [ fhdl, error ] = plotScatt( fx, fxlab, fy, fylab, tags, ssamp, ftitle )
%
% PLTSCATT displays the information of the selected sample
% FX:       feature to plot in the X-axe
% FXLAB:	is the label to be displayed in the X-axe
% FY:       feature to plot in the Y-axe
% FYLAB:	is the label to be displayed in the Y-axe
% TAGS:     a string list of tags. One tag for sample
% SSAMP:	a selected sample to be plotted with an special mark
% FTITLE:   figure title
% FHDL:     handle for the newly created figure

%% === INIT
fhdl = [];
error = {};

%% === ERROR CHECKING
if length(fx) ~= length(fy)
    error = [error, ...
        {'ERROR: EEMlab:plotScatt:numberOfDimensionsMismatch'}];
    return;
end

%% === PLOT
fhdl = figure('NumberTitle','off', 'Name','Scatter Plot', 'WindowStyle','normal');
datacursormode on;

if isempty(tags)
    plot(fx,fy,'g.');
else
    gscatter(fx,fy,tags);
%     lhdl = findobj(fhdl, 'Tag','legend'); % legend handle
%     lhdl.String = ['TITLE', lhdl.String{:}];
end

rangeX = max(fx) - min(fx);
gapX = 0.1*rangeX;
rangeY = max(fy) - min(fy);
gapY = 0.1*rangeY;
minXAxe = min(fx)-gapX;
maxXAxe = max(fx)+gapX;
minYAxe = min(fy)-gapY;
maxYAxe = max(fy)+gapY;
if ~isempty(ssamp)
    hold on;
    scatter(fx(ssamp),fy(ssamp),6,'or','filled');
    plot([fx(ssamp) fx(ssamp)],[minYAxe maxYAxe],':k', 'LineWidth',1);
    plot([minXAxe maxXAxe],[fy(ssamp) fy(ssamp)],':k', 'LineWidth',1)
    hold off;
end

if  rangeY~=0 && rangeX~=0
    axis([minXAxe maxXAxe minYAxe maxYAxe]);
end
set(gca, 'FontSize',8, 'FontWeight','normal');
grid on;
title(ftitle, 'FontSize',8, 'FontWeight','normal');
xlabel(fxlab, 'FontSize',8, 'FontWeight','normal');
ylabel(fylab, 'FontSize',8, 'FontWeight','normal');

end