function [ X, Emmat, Exmat, filelist, error ] = formateems( varargin )

% ----->>>>>   REFEEEERRRRRR

%READINEEMS4QMS reads in QuantaMaster fluorometer files of txt format in
%the current directory and convert to a 3D matrix of EEMs. Please remove
%non-EEM files of specified format from the current directory before
%running. The files will be loaded in alphabetical order (see outputed file
%list). Input EEMs must be of the same size, type and format with same Ex
%and Em.
%
%   INTERNAL FUNCTIONS:
%   QMS2EEM, GETFILESINFOLDER
%
%   USAGE:
%
%   INPUTS:
%   If there are no inputs the function processes all the files in the
%   current directory. If we pass one input, varargin{1} is the concrete
%   list of files (cell array) to be processed

% PARSING INPUTS
if isempty(varargin)
    rflag = false; % recursive flag
    pflag = false; % prepend flag
    files = getfilesinfolder('.',rflag,pflag);
else
    files = varargin{1};
end
if ~iscell(files) % just a file name passed as string argument
    files = cellstr(files);
end
nfiles = length(files);

% INIT
X = [];
Emmat = [];
Exmat = [];
filelist = cell(nfiles,1);
error = cell(nfiles,1);
ok = nan(1,nfiles); % index for valid EEMs

%getting values for the first time to preallocate variables for speed
%we suppose that the first file in a VALID file. Otherwise the load will
%fail for all the files in folder
i = 1;
err = {'not empty'};
while ~isempty(err)
    [~,~,~,ex_test,em_test,err] = qms2mat(files{i});
    error{i} = [err{:} '. File ''' files{i} ''' NOT loaded in the dataset'];
    i = i + 1;
    if i > nfiles+1 % NONE of the files in directory is valid
        return;
    end
end
Exmat = nan(nfiles,length(ex_test));
Emmat = nan(length(em_test),nfiles); % preallocate variable for speed
X = nan(nfiles,length(em_test),length(ex_test));
error = cell(nfiles,1); % reset the error log

% start iterations for every file in directory
for i = 1 : nfiles
    disp(files{i});
    [~,eem_COR,~,ex,em,err] = qms2mat(files{i});
    if isempty(err)
        if length(ex) == 1
            error{i} = ['ERROR readineems4qms:wrongExcitationLength. The file ''', ...
                files{i} ''' is not a matrix as it is excited to only one wavelength.', ...
                ' Try to use ''readinscans4qms'' instead'];
            continue;
        end
        if ~isequal(ex,ex_test)
            error{i} = ['ERROR readineems4qms:excitationArrayMismatch. File ', ...
                files{i} ' not loaded in the dataset'];
            continue;
        end
        if ~isequal(em,em_test)
            error{i} = ['ERROR readineems4qms:emissionArrayMismatch. File ', ...
                files{i} ' not loaded in the dataset'];
            continue;
        end
        Exmat(i,:) = ex;
        Emmat(:,i) = em';
        X(i,:,:) = eem_COR;
        filelist(i) = files(i);
        ok(i) = 1;
    else
        error{i} = [err{:} '. File ''' files{i} ''' not loaded in the dataset'];
    end
end

% remove empty cells
Exmat = Exmat(~isnan(ok),:);
Emmat = Emmat(:,~isnan(ok));
X = X(~isnan(ok),:,:);
filelist = filelist(~isnan(ok),:);
filelist = char(filelist{:}); % transform cell array 'filelist' into a matrix of strings (as in drEEM)
error = error(isnan(ok));

end