function [ filelist ] = getfilesinfolder ( folder, recursive, prepend )
%GETFILESINFOLDER list the files located into the FOLDER passed as 
%parameter. The full path is listed if PREPEND option is enabled. It also 
%enables the RECURSIVE listing of all the files contained in folders and 
%subfolders.

dirData = dir(folder); % get the data for the current directory
dirIndex = [dirData.isdir]; % find the index for directories
filelist = {dirData(~dirIndex).name}'; % get a list of the files
if recursive
    subDirs = {dirData(dirIndex).name}; % get a list of the subdirectories
    validIndex = ~ismember(subDirs,{'.','..'}); % find index of subdirectories that are not '.' or '..'
    for iDir = find(validIndex) % loop over valid subdirectories
        nextDir = fullfile(folder,subDirs{iDir}); % get the subdirectory path
        filelist = [filelist; getfilesinfolder(nextDir,recursive,prepend)]; % recursively call getfilesinfolder
    end
end
if ~isempty(filelist) && prepend
	filelist = cellfun(@(x) fullfile(folder,x),filelist,'UniformOutput',false);
end

end