function [ types, error ] = getlogtypes( filename )
%READLOGTYPES generates the 'strings' parameter for drEEM's 'readlogfile'
%It is supposed that the 1st line in the file is the header. The 2nd line
%in the file is a valid data line. So data types are extracted accordingly
%to the info in this 2nd line. Type help readlogfile for more information.
%
%OUTPUTS:
%	TYPES: specify which columns contain numbers versus text using zero for
%   numbers and 1 for text

% init
types = [];
error = {};

ind = strfind(filename,'.');
ext = filename(ind(end)+1:end);
switch ext
    case 'csv'
        % CAUTION! csvread does not work with string values!!!
        fid = fopen(filename);
        header = fgets(fid); % we suppose that the 1st line is the header, we read and advance!
        dataline = fgets(fid); % 2nd line are data
        fclose(fid); % we close the file
        blocks = regexp(dataline,',','split'); % split csv fields on data line into a cell
        ndata = length(blocks); % number of data to be processed
        types = ones(1,ndata); % all data are suppoed to be string values
        for i = 1 : ndata
            data = blocks{i};
            ind = regexp(data,'[0123456789.]');
            if length(data) == length(ind) % all the characters are a number or the '.'
                types(i) = 0; % then the data is numerical
            end
        end
        
    %WE DO NOT NEED THIS IN XLSX FILES AS DATA TYPE IS AUTOMATICALLY 
    %EXTRACTED FROM EXCEL METADATA
    case {'xls', 'xlsx'}
        [~,~,raw] = xlsread(filename);
        header = raw(1,:); % 1st line is the header
        dataline = raw(2,:); % 2nd line are data
        %kk=cellfun(@isnan,data, 'UniformOutput', false)
        types = double(cellfun(@ischar,dataline));
        
    otherwise
        error = {'ERROR getlogtypes:wrongFileFormat. This file format is not supported'};
end
end