function [ eem, ex, em, error ] = htiFL2mat( filename )
%JSC2MAT imports EEM raw data from a JASCO FP8300 TXT-formatted fluorometer file
%   A native JASCO FP8300 file is TXT formatted
%   The TXT reflects exactly what GXZ contains
%   'eem_raw' are raw intensity values
%
%   This script generates extra information that is not used but can be
%   very useful for future versions and an EEMs database implementation (
%   date, acquisition, sources...)

% init
error = {};
eem = [];
ex = [];
em = [];

    
% data load
[~,~,raw] = xlsread(filename);
if (find(strcmp(raw(:,3),'F-2700 FL Spectrophotometer'),1)) % checking file structure
    
    % em array
    ind = find(strcmp(raw(:,1),'Data points'),1);   % spreadsheet row where dataset starts
    first_ex_in_txt = raw{ind+2,2}(1:find(raw{ind+2,2} == '/')-1);
    next_ex_in_txt = raw{ind+2,2}(1:find(raw{ind+2,2} == '/')-1);
    while strcmp(next_ex_in_txt, first_ex_in_txt)
        new_em = str2double(raw{ind+2,2}(find(raw{ind+2,2} == '/')+1:end));
        em = [em new_em];
        ind = ind + 1;
        next_ex_in_txt = raw{ind+2,2}(1:find(raw{ind+2,2} == '/')-1);
    end
    
    % ex array & eem
    ind = find(strcmp(raw(:,1),'Data points'),1);   % spreadsheet row where dataset starts
    ex =  str2double(raw{ind+2,2}(1:find(raw{ind+2,2} == '/')-1));
    last_ex = ex(end);
    eem_col = [];
    for i = ind+2 : size(raw,1)
        new_ex =  str2double(raw{i,2}(1:find(raw{i,2} == '/')-1));
        new_eem = raw{i,3};
        if new_ex == last_ex
            eem_col = [eem_col; new_eem];
        else
            ex = [ex new_ex];
            last_ex = ex(end);
            eem = [eem eem_col];
            eem_col = new_eem;
        end
    end
    eem = [eem eem_col];

else
    error{end+1} = 'ERROR htiFL2mat:hitachiFileFormatWrong';
    return;
end

end