function [ abs, wls, units, error ] = jen2mat( filename )
%JEN2MAT imports absorbance values from a JENWAY 7315 spectrophotometer TXT 
%formatted file. Absorbance values (ABS) and wavelengths (WLS) are imported
%in ROWS
%
%	The script generates extra information that is not used but can be very
%	useful for future versions and an EEMs database implementation . This
%	information is labelled with (*)

% init
error = {};
abs = [];
wls = [];
units = 'AU'; % Absorbance Units (AU)
pflag = false; % plot flag, for debugging

% error checking
if ~exist(filename,'file')
    error = {'ERROR EEMlab:jen2mat:fileNotExist'};
    return;
end

% data load
fstring = fileread(filename);
fblocks = regexp(fstring, 'nm,Abs', 'split');

% BLOCK 1 processing
% HEADER block. PARAMS: name, date, wl_start, end, step & wls
block = fblocks{1}; % block 1
strpatt = extractBetween(block, 'Scan Start, ', char([13 10]));
wl_start = str2double(strpatt{:});
strpatt = extractBetween(block, 'Scan End, ', char([13 10]));
wl_end = str2double(strpatt{:});
strpatt = extractBetween(block, 'Scan Interval,', char([13 10]));
wl_step = str2double(strpatt{:});
strpatt = extractBetween(block, 'Run Time/Date,', char([13 10]));
timedate = strpatt{:};
wls = wl_start : wl_step : wl_end;
wl_unit = 'nm';

% BLOCK 2 processing
% HEADER block. PARAMS: name, date, wl_start, end, step & speed
block = fblocks{2}; % block 2
lines = textscan(block,'%s','Delimiter','\r'); % read lines
lines{:}(1) = []; % delete 1st EMPTY row
% length(lines{:}) == length(wls)
abs = zeros(1, length(wls));
for i=1:length(lines{:})
    line = textscan(lines{:}{i},'%f','Delimiter',', ');
    %wls(i) = line{:}(1);
    abs(i) = line{:}(3);
end

if (pflag)
    figure;
    plot(wls,abs);
    xlabel(['wavelength (' wl_unit ')']);
    ylabel(['absorbance (' units ')']);
    title('Absorbance');
    range = max(abs) - min(abs);
    axis([wl_start wl_end min(abs)-0.1*range max(abs)+0.1*range]);
    grid on;
end

end
