function [ data, error ] = readxlslogfile( filename )
%READXLSLOGFILE reads a Excel 'xls' or 'xlsx' log file and returns a 
%SampleLog data struct. This function overloads the 'csv' 'readlogfile'
%included in the drEEM toolbox

% init
data = struct();
error = {};

ind = strfind(filename,'.'); % we get file extension
format = upper(filename(ind(end)+1:end));
switch format
    case {'XLX', 'XLSX'}
        [num,txt,raw] = xlsread(filename); % data load
        header = txt(1,:);
        ndata = length(header);
        for i = 1 : ndata
            fieldname = header{i};
            fieldname(isspace(fieldname)) = []; % remove all blank spaces in the header
            if ischar(raw{2,i}) || isnan(raw{2,i}) % text metadata
                data.(fieldname) = strtrim(txt(2:end,i)); % 1st row in txt is the header. Remove leading and trailing blank spaces
            else % numerical metadata
                data.(fieldname) = num(:,i);
            end
        end
    otherwise
        error = {'ERROR readxlslogfile:wrongFileFormat. This is not a ''xls'' or ''xlsx'' file'};
end
end