function [ in, out, error ] = targetsinlist( targets, list, deblank )
%TARGETSINLIST returns the items in the target list that are included in
%the list (IN). It also returns the target items not included in the list
%(OUT). Items in LIST and TARGETS can be both numerical or string items. If
%they are string, white characters are removed before checking
%Input parametre DEBLANK (bool) deletes white spaces in both LIST and
%TARGETS before matching

% init
in = cell(length(targets),1);
out = cell(length(targets),1);
error = {};

% data normalisation, all the items are transformed into cell items
if ~iscell(targets)
    if isnumeric(targets)
        targets = cellstr(num2str(targets(:)));
    elseif ischar(targets) % targets list in rows
        targets = cellstr(targets);
    end
end
if ~iscell(list)
    if isnumeric(list)
        list = cellstr(num2str(list(:)));
    elseif ischar(list)
        list = cellstr(list);
    end
end

% put both lists in column format
if size(targets,2) > 1
    targets = targets';
end
if size(list,2) > 1
    list = list';
end

% deletes white space characters from input lists
if deblank
    for i = 1 : length(targets)
        listitem = targets{i};
        listitem(isspace(listitem)) = [];
        targets{i} = listitem;
    end
    for i = 1 : length(list)
        listitem = list{i};
        listitem(isspace(listitem)) = [];
        list{i} = listitem;
    end
end

% if exists, eliminates repeated values from both input lists
targets = unique(targets);
list = unique(list);

% look for targets in list
for i = 1 : length(targets)
    item = targets{i};
    if ischar(item)
        matches = find(strcmpi(item,list) == 1);
    elseif isnumeric(item)
        matches = find(cell2mat(list) == item);
    end
    if isempty(matches)
        out{i} = item;
    else
        in{i} = item;
    end
end

% remove preallocated empty cells
in(cellfun(@isempty,in)) = [];
out(cellfun(@isempty,out)) = [];

if isempty(in)
    % NO matches between targets and list items
    error = {'ERROR targetsinlist:noTargetsInList'};
end

end