function [ cellarray, error ] = txtfile2cellarray( filename )
%
%TXTFILE2CELLARRAY reads a TXT file and returns a cell array. Each array
%component is a line in the TXT file

% init
cellarray = {};
error = {};

if exist(filename,'file') == 2
    numLines = nlines(filename);
    cellarray = cell(1,numLines);
    fid = fopen(filename,'r');
    line = 1;
    while ~feof(fid)
        % '\r\n' is the line feed
        text = textscan(fid,'%s',1,'Delimiter','\r\n');
        cellarray(line) = text{:};
        line = line + 1;
    end
    fclose(fid);
else
    error = {'ERROR txtfile2cellarray:fileDoesNotExist'};
end

end

%%%% sub-functions
%
function [ numLines ] = nlines( filename )
%
%NLINES returns the number of lines in a TXT file

% reading the number of lines
fid = fopen(filename,'rb');
% get file size
fseek(fid,0,'eof');
fileSize = ftell(fid);
frewind(fid);
% read the whole file
data = fread(fid,fileSize,'uint8');
% count number of line-feeds (the ASCII value is '10') and increase by one
numLines = sum(data == 10) + 1;
fclose(fid);
end